@@ -1,7 +1,7 @@
 package App::GamesWordlist;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2016-01-18'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -302,18 +302,12 @@ App::GamesWordlist - Grep words from Games::Word::{Wordlist,Phraselist}::*
 
 =head1 VERSION
 
-This document describes version 0.14 of App::GamesWordlist (from Perl distribution App-GamesWordlist), released on 2016-01-07.
+This document describes version 0.15 of App::GamesWordlist (from Perl distribution App-GamesWordlist), released on 2016-01-18.
 
 =head1 SYNOPSIS
 
 See the included script L<games-wordlist>.
 
-=head1 SEE ALSO
-
-L<Games::Word::Wordlist>
-
-L<Games::Word::Phraselist>
-
 =head1 FUNCTIONS
 
 
@@ -400,7 +394,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-GamesW
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-wordlist>.
+Source repository is at L<https://github.com/perlancar/perl-App-GamesWordlist>.
 
 =head1 BUGS
 
@@ -410,6 +404,14 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<App::wordlist> which greps C<WordList::*> modules instead.
+
+L<Games::Word::Wordlist>
+
+L<Games::Word::Phraselist>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
